Description class

Marks a handler with an OpenAPI description (detailed explanation).

@Description('Returns a paginated list of all registered users.')
FutureOr<dynamic> listUsers(EngineContext ctx) { ... }

Constructors

Description(String value)
Creates a description annotation with value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The detailed OpenAPI description.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited