OperationId class

Sets the OpenAPI operationId for a handler.

@OperationId('listUsers')
FutureOr<dynamic> listUsers(EngineContext ctx) { ... }

Constructors

OperationId(String value)
Creates an operation ID annotation with value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The stable OpenAPI operation ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited