OpenApiRequestBody class
Describes a request body.
Constructors
-
OpenApiRequestBody({String? description, bool required = false, Map<
String, OpenApiMediaType> content = const {}}) -
Creates a request body with its content definitions.
const
-
OpenApiRequestBody.fromJson(Map<
String, Object?> json) -
Deserializes a request body from
json.factory
Properties
-
content
→ Map<
String, OpenApiMediaType> -
Media types accepted for this body, keyed by MIME type.
final
- description → String?
-
A human-readable description of the body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- required → bool
-
Whether the operation requires this body.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the request body to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited