OpenApiTag class
An OpenAPI tag for grouping operations.
Constructors
- OpenApiTag({required String name, String? description})
-
Creates a tag named
name.const -
OpenApiTag.fromJson(Map<
String, Object?> json) -
Deserializes a tag from
json.factory
Properties
- description → String?
-
An optional explanation of the tag.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The tag name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the tag to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited